import os


class Packages:
    def __init__(self):
        self.packages = self._get_packages()

    def __str__(self):
        # Run pip list command
        return str(os.popen('pip list').read())

    def __iter__(self):
        # Pack packages dictionary into a list of tuples
        return iter([(name, version) for name, version in self.packages.items()])

    @staticmethod
    def _get_packages():
        """Retrieve a list of installed pacakges"""
        # Run pip freeze command
        pip_freeze = os.popen('pip freeze').read()

        # Create dictionary of packages
        return {package.split('==')[0]: package.split('==')[1] for package in pip_freeze.strip().split('\n')}

    def installed(self, package_name):
        """
        Check if a particular Python package is installed.

        :param package_name: Name of the package
        :return: True or False
        """
        status = True if package_name.lower() in [str(key.lower()) for key in self.packages.keys()] else False
        return status


def main():
    print(Packages())


if __name__ == '__main__':
    main()



from envinfo.system import System

# Windows only, get information on mounted drives
if System().os == 'Windows':
    from os import popen
    from re import findall, MULTILINE
    from string import ascii_uppercase
    from ctypes import windll


    class Drives:
        def __init__(self):
            self.drives = self._get_drives()
            self.drives_local = self._get_drives_local()

        def __str__(self):
            return str(self.drives)

        def __iter__(self):
            return iter(self.drives)

        @staticmethod
        def _get_drives():
            """Get list of all network and locally mounted drives"""
            drives = []
            bitmask = windll.kernel32.GetLogicalDrives()
            for letter in ascii_uppercase:
                if bitmask & 1:
                    drives.append(letter)
                bitmask >>= 1

            return ['{0}:\\'.format(d) for d in drives]

        @staticmethod
        def _get_drives_local():
            """Get list of locally mounted drives"""
            return findall(r"[A-Z]+:.*$", popen("mountvol /").read(), MULTILINE)


    def main():
        print(Drives())


    if __name__ == '__main__':
        main()


else:
    print("envinfo.drives module is compatible with Windows platform's only")



from envinfo.system import EnvInfo
from envinfo.package import Packages


__all__ = ['EnvInfo', 'Packages']


# Import and add Drives to __all__ declaration if running on Windows
if EnvInfo().system.os == 'Windows':
    from envinfo.drives import Drives
    __all__.append('Drives')
